# The MIT License (MIT)
# Supplementary Material to Article : 
# P. A. Araya Melo, M. Crucifix, N. Bounceur, 
# Global sensitivity analysis of Indian Monsoon during the Pleistocene
# http://www.clim-past-discuss.net/10/1609/2014/cpd-10-1609-2014.html
# 
# Copyright (c) 2014 Michel Crucifix
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
# 

verbose=TRUE 
  
 require(GP) 
 require(Hmisc) 

 RDatapath = file.path('..','Data','RData')
 load(file.path(RDatapath,'exp_output.rda'))
 load(file.path(RDatapath,'lambda.rda'))

 # calibrate a list of emulators 
 # using the lambdas defined above 



 ELIST <- lapply(names(Lambdas), function(exp) 
          {
          o = lapply(names(Lambdas[[exp]]), function(var)
                 return ( GP_C ( DATA[[exp]]$X, DATA[[exp]]$Y[,var], Lambdas[[exp]][[var]] ) )) 
                 
          names(o) = names(Lambdas[[exp]])
          return(o)
           }  )

 # leave-one-out diagnostics 

 L1O_LIST <- lapply(names(Lambdas), function(exp) 
          {
          o = lapply(names(Lambdas[[exp]]), function(var)
                 return ( L1O ( DATA[[exp]]$X, DATA[[exp]]$Y[,var], Lambdas[[exp]][[var]] ) )) 
                 
          names(o) = names(Lambdas[[exp]])
          return(o)
           }  )



 names(ELIST) <- names(Lambdas)
 names(L1O_LIST) <- names(DATA)

# helper function to print L1O diagnostic

 print_l1o <- function(l1o)
 {
  with (l1o, errbar( Yi, mean,  mean-sd, mean+sd) )
  lines(c(-100, 100), c(-100,100), lty=2)
 }

# e.g.: print_l1o(L1O_LIST$Orog_full$temp2)

# for example, compare 

#> print_l1o(L1O_LIST$Orog_full$sst)
#> print_l1o(L1O_LIST$Orog_without_11_40$sst)
