# The MIT License (MIT)
# Supplementary Material to Article : 
# P. A. Araya Melo, M. Crucifix, N. Bounceur, 
# Global sensitivity analysis of Indian Monsoon during the Pleistocene
# http://www.clim-past-discuss.net/10/1609/2014/cpd-10-1609-2014.html
# 
# Copyright (c) 2014 Michel Crucifix
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
# construct a density array for esinw, ecosw, eps, etc. 

rhocalc <- function(scales,shifts, n=c(ecosw=8, esinw=8, eps=8, co2=8, ice=8))
{

  require(palinsol)

  times=seq(-2000,0,1)*1000

  O = sapply(times,ber78)

  esinw = ( O['ecc', ]  * sin ( O['varpi', ]) - shifts['esinw'] ) / scales['esinw']
  print(esinw)
  eps   = ( O['eps', ]  - shifts['eps']  ) / scales['eps']
  print(eps)
 
  # boundaries of the histograms to be created
  # +1 = one more boundary than the number of categories
  
  xs = seq(-0.20, 1.20, l=n['ecosw']+1)
  ys = seq(-0.20, 1.20, l=n['esinw']+1)
  zs = seq(-0.00, 0.90, l=n['eps']+1)

  print(c(xs,ys,zs))
  # the xh, yh and zh are the centers of the histogram bars
  # and will be used as center points for the numerical estimates
  # of the integrals

  xh <- hist(esinw, breaks=xs,  plot=FALSE)
  yh <- xh
  zh <- hist(eps, breaks=zs,  plot=FALSE)

  x        <- expand.grid(xh$mids, xh$mids, zh$mids)
  rhoastro <- outer(outer(xh$density,xh$density),zh$density) 

  # dimnames(rhoastro) <- list('esinw','ecosw','eps')

  # at this stage we do have a (non-normalised) rhoarray for the three main astronomical dimensions
  # we must now compound this with co2. Two options : 
  # either we consider an histogram based on real data, or either
  # we consider an idealised density function
  # let us begin with the later

  levels <- list(co2=seq(0,1,l=n['co2']), ice=seq(0,1,l=n['ice']))
  sqrt3 <- 1./sqrt(3.)
  rhoiceco2 <- outer(levels$co2, levels$ice,  
                     function(co2,ice) 
                     { 
                       # rescaling as Pablo uses [0,1] intervals, rather
                       # than [-1,1] in the orginal development
                       c <- 2 * co2 - 1
                       i <- 2 * ice - 1
                       dnorm (sqrt3*(2*c + i)  )   *
                       dnorm (sqrt3*(+c + 2*i) ) 
                     }
                    )

  # combine and normalise
  rho <- outer(rhoastro,rhoiceco2)
  rho <- rho / sum(rho)

  # update levels and return
  # alas if this was python I would just dereference the last two arguments, but don't know
  # how to do this in R

  attr(rho,'levels') <- list(esinw=xh$mids, ecosw=yh$mids, eps=zh$mids, co2=levels$co2, ice=levels$ice)
  rho 

}

