# The MIT License (MIT)
# Supplementary Material to Article : 
# P. A. Araya Melo, M. Crucifix, N. Bounceur, 
# Global sensitivity analysis of Indian Monsoon during the Pleistocene
# http://www.clim-past-discuss.net/10/1609/2014/cpd-10-1609-2014.html
# 
# Copyright (c) 2014 Michel Crucifix
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
# load input data
 
 RDatapath = file.path('..','Data','RData')
 load(file.path(RDatapath,'exp_output.rda'))
 load(file.path(RDatapath,'lambda.rda'))

 # this is the routine to estimate density in phase space 
 source('./rhoarray.R')

 require(GP)
 # produces emulator

 exp = "Orog_full"
 vars = colnames(DATA$Orog_full$Y)
 names(vars) = vars


 X = DATA[[exp]]$X
 E = lapply(vars, function(var)  GP_C ( DATA[[exp]]$X, DATA[[exp]]$Y[,var], Lambdas[[exp]][[var]] )  ) 

 rho <- rhocalc(attr(X,"scales"), attr(X,"shifts"), n=c(ecosw=8, esinw=8, eps=8, co2=8, ice=8) )


 # ok. how this works: 
 # the GP package supplies a routine called 'varanal' which performs
 # a variance analysis by performing the integral in a 'brute-force' way, i.e.
 # simply by estimating the integral by a sum rule, deviding the space into 
 # n times n times n etc. grid points
 # this is not optimal (and we don't do so in future papers) but this is 
 # a deterministic estimator and comparison with MC estimates suggest it is not so bad
 # afterall 

 # varanal works as fallows (see also the package documentation)

 # varanal will estimate the emulator variances (more precisely, integral 
 # of squared quantities !) associated with the variance of indices
 # complementary to "p" (-p in the notation of Oakley and Ohagan), 
 # and then take the expectation of this quantity over 'p'. 

 # the less indices in "p", the more computationally intensive
 # given that all (-p) x (-p) combinations have to be summed up. 

 # variances measures will then be obtained as follows, 
 # e.g.: 
 #     (-)   total sensitivty index associated with, e.g., vars 1 and 2 :
 #           varanal(E, rho, c(1,2,3,4,5))  - varanal(E, rho, c(3,4,5))
 #     (-)   mean sensitivty index associated with the same variables
 #           varanal(E, rho, c(1,2) ) - varanal (E, rho, NULL ) 

 # the various output indices have the following meaning: 
 # ev : "emulator variance"
 # sv : "simulator variance"
 # svm : "simulator variance associated with the variance of the mean" (not used here)
 # svmg : "simulator variance associated with the covariance of the mean / gaussian" (not used here)
 # svg : "simulator variance associated with thegaussian" (not used here)

 varanal_list = list(c(3,4,5), c(1,2,4,5), c(1,2,3,5), c(1,2,3,4), c(1,2,3,4,5))
 #varanal_list = list(c(4), c(5), c(4,5), NULL)
 #varanal_list = list(c(1), c(1,2), c(1,2,3), c(1,2,3,4), c(1,2,3,4,5))

 VA <- sapply(seq(along=E), 
              function(i) sapply(varanal_list, 
                                 function(j) unlist(varanal(E[[i]],rho,j)),
                                 USE.NAMES=TRUE))
#
 save(file='VA_conjugate.rda', VA)
 VA <- array (VA, dim=c(5,5,4))
 dimnames(VA) <- list(c('ev','sv','svm','svmg','svg'), 
                      c('precess','obl','co2','ice','REF'), 
#                #      c('co2','ice','co2ice','REF'), 
#                #      c('1','12','123','1234','12345'),
                      names(Lambdas[[exp]]))
#
#

save(VA, file=file.path(RDatapath, 'VA_conjugate.rda'))
